"""
Dies ist das Konfigurationsfile. Hier bitte nach eigenen Gegebenheiten eintragen. soc_helper entdeckt Schreibzugriffe auf die Datei
und liest sie neu ein. Bitte trotzdem die Ausgabe in nohup.out oder auf der Konsole beachten, falls etwas ungültiges abgespeichert wurde.
"""

"""
Spritmonitor-Konfiguration.
WICHTIG: Es muß eine gültige Umgebungsvariable SPRITMONITOR_BEARER_TOKEN geben. Diese kann bei Spritmonitor.de
auf der Passwort-Vergessen-Seite angefordert werden. Eine Umgebungsvariable wird verwendet, damit nicht aus
versehen der Zugang mit verschickt wird, wenn der Code weitregegeben oder veröffentlicht wird. Sie wird vor Aufruf
von soc_helper.py mittels "export SPRITMONITOR_BEARER_TOKEN=<eigenerToken>" deklariert - idealerweise in der Datei
~/.profile schon bei der Anmeldung am System.
"""
USE_SPRITMONITOR = True               # Auf False setzen, falls Übertragung nicht erfolgen soll
SPRITMONITOR_VEHICLE_ID = '1370192'   # Bitte hier die eigene Fahrzeug-ID (In der App oder Webseite angezeigt) einfügen
SPRITMONITOR_APP_TOKEN = '4a5379db9f8530b11096ff4c917bdc9a' # App-Token für dieses Programm. Nötig für die API-Nutzung von Spritmonitor
SPRITMONITOR_FUELSORT = 24            # über die Api sind die Nummern der Kraftstoffsorten abrufbar. Hier wichtig: 19 - Elektrizität, 24 - Ökostrom
SPRITMONITOR_FUELPRICE = 0.359        # Preis in €/kWh. Bei reinem PV-Laden die Einspeisevergütung plus evt. Umsatzsteuer auf Eigenverbrauch. 
# folgende Attribute können der Betankung per default zugefügt werden (maximal je eines pro Zeile aussuchen):
# Reifen: summertires wintertires allyeartires
# Fahrweise: slow normal fast
# Mit Klima: ac
# Mit Anhänger: trailer
# Mit Standheizung: heating
SPRITMONITOR_ATTRIBUTES = 'wintertires,slow'
"""
CAN. Siehe CAN-Datenbank VW: https://www.goingelectric.de/wiki/Liste-der-OBD2-Codes/
"""
# CAN-Botschaftsdefinition, um SOC anzufordern
VALID_SOC_ID=2029   #ID der Antwort-Botschaft, in der der SOC steht. e-up: 2029 - Antwort des Batterie-SG
SOC_REQUEST = '{ \"bus\": \"0\", \"type\": \"tx\", \"frame\": [{ \"id\": 2021, \"dlc\": 8, \"rtr\": false, \"extd\": false, \"data\": [3, 34, 2, 140, 170, 170, 170, 170] }] }'
VALID_SOC_ANSWER=[98,2,140] #die Bytes, mit der die SOC-Anforderung quittiert wird. e-up: Anforderung ist 34,2,140, Antwort 98,2,140, danach folgt der [SOC in %]*2.55
# CAN-Definition, um den Kilometerstand anzufordern
VALID_DST_ID=1918   #ID der Antwort-Botschaft, in dem der SOC steht. e-up: 1918 - Antwort des Schalttafel-Einsatzes
DST_REQUEST = '{ \"bus\": \"0\", \"type\": \"tx\", \"frame\": [{ \"id\": 1812, \"dlc\": 8, \"rtr\": false, \"extd\": false, \"data\": [3, 34, 34, 3, 170, 170, 170, 170] }] }'
VALID_DST_ANSWER=[98,34,3] #die Bytes, mit der die Distance-Anforderung quittiert wird. e-up: Anforderung ist 34,34,3, Antwort 98,34,4, danach folgen zwei Bytes aa bb mit ODO=(aa*256+bb)*10

"""
#OPENWB-Konfiguration
"""
OPENWB_IP = '192.168.1.102' # hier die Adresse der OpenWB einstellen - Lokaler Name könnte auch funktionieren, nicht ausprobiert

# Die folgenden Topics hängen von der Konfiguration der OpenWB ab. Wichtig ist, die Zahlen (IDs) richtig zu setzen.:Sie sind in
# Firmware 2.0 auf der Statusseite zu finden.

#Für OpenWB 2.x:
OPENWB_SETSOC_TOPIC = 'openWB/set/vehicle/0/soc_module/calculated_soc_state/manual_soc' # Topic zum Setzen des manuellen SOC. Anscheinend hat um den 14.10.2023 herum das Topic gewechselt
OPENWB_GETSOC_TOPIC = 'openWB/vehicle/0/get/soc' # Topic, um den SOC-Wert der Wallbox auszulesen
OPENWB_CHARGECOUNTER_TOPIC = 'openWB/chargepoint/3/get/imported' # Topic, um den Ladezähler auszulesen. Insbesondere die Nummer ist anzupassen
OPENWB_GETPLUGSTATE_TOPIC = 'openWB/chargepoint/3/get/plug_state' # Topic, um den Steckerzustand auszulesen. Nummer anpassen!
OPENWB_FACTORCOUNTER = 1000 # Faktor, um von der Einheit des Zählers (in 2.0 sind es Wh) auf kWh umzurechnen

#Für OpenWB 1.9:
#OPENWB_SETSOC_TOPIC='openWB/set/lp/1/manualSoc' #das Topic, auf das der ermittelte SOC geschrieben werden soll.
#OPENWB_GETSOC_TOPIC='openWB/lp/1/%Soc' #Topic, um den SOC-Wert der Wallbox auszulesen
#OPENWB_CHARGECOUNTER_TOPIC='openWB/lp/1/kWhCounter' #Topic, um den Ladezähler auszulesen. Bei 1.9 in kWh, bei 2.0 in Wh!
#OPENWB_GETPLUGSTATE_TOPIC='openWB/lp/1/boolPlugStat' #Topic, um den Steckerzustand auszulesen.
#OPENWB_FACTORCOUNTER=1 #Faktor, um von der Einheit des Zählers (in 1.9 sind es kWh) auf kWh umzurechnen

"""
WiCAN
"""
TOPIC_PREFIX = 'wican/34b472f22a8d' # hinter wican/ folgt die 12-stellige ID des Gerätes. Sie ist dem Namen des WLAN-APs des WiCAN zu entnehmen

"""
Sonstiges
"""
# Zum Loglevel:
# 0 - nur das allerwichtigste: Prgrammstart, Fehler, Abbrüche
# 1 - Wichtige Schritte für die Arbeit des soc_helper
# 2 - Feine Logausgabe
# 3 und höher zur Zeit nicht genutzt
LOGLEVEL = 2
# In das Chargelog werden die Daten der Ladevorgänge geschrieben: Start-SOC, Kilometerstand, Energiemenge, End-SOC laut Wallbox
CHARGELOG_PATH = '/home/pi/soc_helper/energydata.csv'

# Berechnungsfunktion des SOC aus der Antwort des Fahrzeugs. Die Antwortbytes des Fahrzeuges auf die SOC-Abfrage stehen in einer Liste "bytes" mit n
# Elementen. Das erste Element hat den Index 1. Die Funktion rechnet aus den Bytes den SOC als Ganzzahl aus und gibt ihn zurück. Beim e-up ist die Liste
# [98 2 140, aa, xx, xx, xx, xx]. aa ist der SOC*2,55, so daß 255 einem SOC von 100% entspricht. Das Ergebnis muß für die OpenWB-SW 1.9 eine Ganzzahl sein,
# die Software 2.x kann Nachkommastellen.
def getSoc(bytes):
    soc = round(bytes[4]/2.55)
    return soc
    
# Berechnungsfunktion des Kilometerstandes aus der Antwort des Fahrzeugs. Die Antwortbytes des Fahrzeuges auf die km-Abfrage stehen in einer Liste "bytes"
# mit n Elementen. Das erste Element hat den Index 1. Die Funktion rechnet aus den Bytes den Kilometerstand als Ganzzahl aus und gibt ihn zurück. Beim
# e-up ist die Liste [98 34 4, aa, bb, xx, xx, xx]. aa ist der Kilometerstand aa*2560+bb*10, d.h. der Kilometerstand wird in Zehnerschritten quantisiert.
def getOdo(bytes):
    odo=bytes[4]*2560+bytes[5]*10
    return odo

